==> qmmp_1.1.10.orig.tar.bz2: qmmp-1.1.10/src/app/translations/qmmp_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="es">
<context>
    <name>BuiltinCommandLineOption</name>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="80"/>
        <source>Skip forward in playlist</source>
        <translation>Avanzar en la lista de reproducción</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="81"/>
        <source>Skip backwards in playlist</source>
        <translation>Retroceder en la lista de reproducción</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="72"/>
        <source>Start playing current song</source>
        <translation>Empezar reproduciendo la canción actual</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="71"/>
        <source>Don&apos;t clear the playlist</source>
        <translation>No limpiar la lista de reproducción</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="73"/>
        <source>Pause current song</source>
        <translation>Pausar la canción actual</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="74"/>
        <source>Pause if playing, play otherwise</source>
        <translation>Pausar si se está reproduciendo, o viceversa</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="75"/>
        <source>Stop current song</source>
        <translation>Detener la canción actual</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="76"/>
        <source>Display Jump to File dialog</source>
        <translation>Mostrar el diálogo Saltar a archivo</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="77"/>
        <source>Quit application</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="78"/>
        <source>Set playback volume (example: qmmp --volume 20)</source>
        <translation>Cambiar el volumen de reproducción (ejemplo: qmmp --volume 20)</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="79"/>
        <source>Mute/Restore volume</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="82"/>
        <source>Show/hide application</source>
        <translation>Mostrar/ocultar aplicación</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="83"/>
        <source>Show main window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="84"/>
        <source>Display Add File dialog</source>
        <translation>Mostrar el diálogo Añadir archivo</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="85"/>
        <source>Display Add Directory dialog</source>
        <translation>Mostrar el diálogo Añadir directorio</translation>
    </message>
</context>
<context>
    <name>QMMPStarter</name>
    <message>
        <location filename="../qmmpstarter.cpp" line="350"/>
        <source>Usage: qmmp [options] [files]</source>
        <translation>Uso: qmmp [opciones] [archivos]</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="351"/>
        <source>Options:</source>
        <translation>Opciones: </translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="357"/>
        <source>Print version number and exit</source>
        <translation>Mostrar el número de versión y salir</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="358"/>
        <source>Ideas, patches, bugreports send to forkotov02@hotmail.ru</source>
        <translation>Enviar ideas, parches, errores a: forkotov02@hotmail.ru</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="361"/>
        <source>Command Line Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="374"/>
        <source>QMMP version: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="375"/>
        <source>Compiled with Qt version: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="376"/>
        <source>Using Qt version: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="379"/>
        <source>Qmmp Version</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="356"/>
        <source>Display this text and exit</source>
        <translation>Muestra este texto y sale</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="95"/>
        <source>Unknown command</source>
        <translation>Comando desconocido</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="355"/>
        <source>Don&apos;t start the application</source>
        <translation>No iniciar la aplicación</translation>
    </message>
</context>
</TS>

==> qmmp_1.2.6.orig.tar.bz2: qmmp-1.2.6/src/app/translations/qmmp_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="es">
<context>
    <name>BuiltinCommandLineOption</name>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="71"/>
        <source>Don&apos;t clear the playlist</source>
        <translation>No limpiar la lista de reproducción</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="72"/>
        <source>Start playing current song</source>
        <translation>Empezar reproduciendo la canción actual</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="73"/>
        <source>Pause current song</source>
        <translation>Pausar la canción actual</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="74"/>
        <source>Pause if playing, play otherwise</source>
        <translation>Pausar si se está reproduciendo, o viceversa</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="75"/>
        <source>Stop current song</source>
        <translation>Detener la canción actual</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="76"/>
        <source>Display Jump to File dialog</source>
        <translation>Mostrar el diálogo Saltar a archivo</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="77"/>
        <source>Quit application</source>
        <translation>Salir de aplicación</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="78"/>
        <source>Set playback volume (example: qmmp --volume 20)</source>
        <translation>Cambiar el volumen de reproducción (ejemplo: qmmp --volume 20)</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="79"/>
        <source>Print volume level</source>
        <translation>Mostrar nivel de volumen</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="80"/>
        <source>Mute/Restore volume</source>
        <translation>Silenciar/Restaurar volumen</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="81"/>
        <source>Print mute status</source>
        <translation>Mostrar estado de silencio</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="82"/>
        <source>Skip forward in playlist</source>
        <translation>Avanzar en la lista de reproducción</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="83"/>
        <source>Skip backwards in playlist</source>
        <translation>Retroceder en la lista de reproducción</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="84"/>
        <source>Show/hide application</source>
        <translation>Mostrar/ocultar aplicación</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="85"/>
        <source>Show main window</source>
        <translation>Mostrar ventana principal</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="86"/>
        <source>Display Add File dialog</source>
        <translation>Mostrar el diálogo Añadir archivo</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="87"/>
        <source>Display Add Directory dialog</source>
        <translation>Mostrar el diálogo Añadir directorio</translation>
    </message>
</context>
<context>
    <name>QMMPStarter</name>
    <message>
        <location filename="../qmmpstarter.cpp" line="109"/>
        <source>Unknown command</source>
        <translation>Comando desconocido</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="373"/>
        <source>Usage: qmmp [options] [files]</source>
        <translation>Uso: qmmp [opciones] [archivos]</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="374"/>
        <source>Options:</source>
        <translation>Opciones: </translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="380"/>
        <source>Start qmmp with the specified user interface</source>
        <translation>Iniciar qmmp con la interfaz de usuario especificada</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="381"/>
        <source>List all available user interfaces</source>
        <translation>Mostrar lista de todas las interfaces de usuario disponibles</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="382"/>
        <source>Don&apos;t start the application</source>
        <translation>No iniciar la aplicación</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="383"/>
        <source>Display this text and exit</source>
        <translation>Muestra este texto y sale</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="384"/>
        <source>Print version number and exit</source>
        <translation>Mostrar el número de versión y salir</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="386"/>
        <source>Home page: %1</source>
        <translation>Página de inicio: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="387"/>
        <source>Development page: %1</source>
        <translation>Página de desarrollo: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="388"/>
        <source>Bug tracker: %1</source>
        <translation>Reporte de errores: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="393"/>
        <source>Command Line Help</source>
        <translation>Ayuda de Consola</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="406"/>
        <source>QMMP version: %1</source>
        <translation>QMMP versión: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="407"/>
        <source>Compiled with Qt version: %1</source>
        <translation>Compilado con Qt versión: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="408"/>
        <source>Using Qt version: %1</source>
        <translation>Usando Qt versión: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="411"/>
        <source>Qmmp Version</source>
        <translation>Versión de Qmmp</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="428"/>
        <source>User Interfaces</source>
        <translation>Interfaz de usuario</translation>
    </message>
</context>
</TS>
